# convert_color_codes

The convert_color_codes module deals with the conversion of color codes. Conversion from these codes HSV/HSB, RGB, CMYK, HSL from one to another.

## Installation

You can install _convert_color_codes_ from PyPI:

```
pip install convert_color_codes
```

It is supported on Python 2, 3 ...

## How to use

``` python
from convert_color_codes import *
```
